%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {[@var{J} @var{DJ}] =} CostFunction (@var{beta}, @var{X}, @var{y})
%% 
%% Calculate the cost function for logistic regression.
%%  
%% Input args:
%% Vector @var{beta} of regression parameters;
%% Regression matrix @var{X};
%% Vector @var{y} of measured data.
%% The elements of @var{y} can be binary data (in form of 0's and 1's),
%% or, more generally, averages over @code{r} realizations of 0's and 1's.
%% The vector @var{y} is taken from the output of @code{readQuest}.
%% 
%% Output:
%% Cost function @var{J} and its partial derivatives @var{DJ}
%% with respect to the components of @var{beta}.
%% The cost function is equivalent (up to a constant factor)
%% to the log-likelihood of the parameter @var{beta} in logistic regression.
%% 
%% @seealso{readQuest, LogReg}
%% 
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function [J, DJ] = CostFunction(beta, X, y)

n = length(y); % number of profiles
J = 0;
DJ = zeros(size(beta));

J = (1/n)*( - y'*log(logistic_function(X*beta))...
            - (1-y')*log(1-logistic_function(X*beta))...
          );

DJ = (1/n)*(X'*(logistic_function(X*beta)-y));
DJ = DJ(:);

end

