%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {@var{y} =} Delta_xj (@var{j}, @var{X}, @var{D})
%% 
%% Calculate the covariance function d(xj,x)
%% for a fixed profile xj in the design @var{X}
%% and for every profile x in the full profile list @var{FD}
%% (@var{FD} is constructed as a global variable within the scope
%% of @code{Run}, to which this function belongs).
%% 
%% Input:
%% Index @var{j} of the @var{j}-th profile xj in @var{X}
%% (calculated as the row number of xj in @var{FD});
%% Dummy-coded regression design matrix @var{X};
%% Inverse matrix @var{D} = inv(@var{X}'*@var{X});
%% 
%% Output:
%% Array @var{y} with the same number of rows as @var{FD},
%% and with @var{y}(i) = d(xj,x(i)),       
%% where x(i) is the i-th profile in @var{FD} (for each i), and
%% d is the covariance function of design @var{X}.
%%              
%% Reference(s):
%% Cook and Nachtsheim, Technometrics 22.3 (1980), Eq.(3)
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function y = Delta_xj(j,X,D)

global FD;

y = - X(j,:)*D*X(j,:)'...
    + dot(FD', D*FD')'...
    - X(j,:)*D*X(j,:)'*dot(FD', D*FD')'...
    + (X(j,:)*D*FD')'.^2;

end
