%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {@var{beta =} LogReg (@var{X}, @var{y})
%% 
%% Perform logistic regression by minimizing the cost function given by
%% @code{CostFunction} with the minimization algorithm @code{fminunc}.
%% 
%% The maximal number of iterations of @code{fminunc} has been set manually to 500.
%% 
%% Input args:
%% Regression matrix @var{X};
%% Vector @var{y} of measured data.
%% The elements of @var{y} can be binary data (in form of 0's and 1's), or, more generally, averages over @code{r} realizations of 0's and 1's.
%% The vector @var{y} is taken from the output of @code{readQuest}.
%% 
%% Output:
%% Vector @var{beta} of estimated regression parameters.
%% 
%% @seealso{CostFunction, fminunc, readQuest}
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function beta = LogReg(X,y)

[n p] = size(X);
initial_beta = zeros(p,1);
options = optimset('GradObj','on','MaxIter',500);

[beta cost] = fminunc(@(beta)(CostFunction(beta,X,y)),initial_beta,options);

end
