%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {@var{Y} =} Run (@var{s}) 
%% 
%% Given the parameter settings @var{s}, run @code{randBD}
%% to construct a random block design, and run the modified Fedorov
%% algorithm @code{mFed_it} to construct a D-optimal regression design.
%% 
%% The full list of profiles @var{FD} is defined and constructed
%% as a global variable within the scope of @code{Run}.
%% The global variable @var{FD} is in turn accessed by the functions @code{mFed_it},
%% @code{mFed} and @code{Delta_xj}.
%% 
%% Input args:
%% Structure @var{s} of parameter settings 
%% (see @code{initsettings}).
%% 
%% Output:
%% Structure @var{y} with fields
%% @code{D}: D-optimal regression matrix (output of @code{mFed_it});
%% @code{B}: matrix representing the random block design (output of @code{randBD}).
%% 
%% @seealso{mFed_it, randBD}.
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function y = Run(s)

global FD;

% ========= random blocks ====================
%
yB = randBD(s.v,s.k,s.b);   
fprintf('Questionnaire split calculated.\r\n');

% ========= modified Fedorov =================
%
fprintf('Initializing mFed...\r\n');
FD = fullDDes(s.pars); 

% remove concurrence profiles from list of candidates
dconcprofs = dumenc(s.concprofs,s.pars);
idx = find(ismember(FD,dconcprofs ,'rows'));
FD(idx,:)= [];

yD = mFed_it(s.v,s.pars,s.mFit);
 
y = struct('D',yD,'B',yB);  

end
