%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {@var{y} =} dumenc (@var{profs}, @var{pars})
%% 
%% Transform a factorial design into dummy-coded form.
%% 
%% Input args:
%% Matrix @var{profs} of profiles written in factorial form (i.e., with levels
%% labeled by integers starting from 1);
%% Array @var{pars} of design parameters
%% (see field @code{pars} in @code{initsettings.m});
%% 
%% Output: dummy-coded matrix @var{y} with intercept column of ones.
%% 
%% @seealso{undummy}.
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function y = dumenc(profs,pars)

dumpars = pars-1;
n=size(profs,1);
y=zeros(n,sum(dumpars));

% dummy-encode the attribute levels
for i=1:n
  for j=1:length(pars)
    colshift = sum(dumpars(1:j-1));
    lev = profs(i,j);
    if lev > dumpars(j)+1
      error('given level exceeds range') 
    elseif lev > 1
      y(i,colshift+lev-1) = 1;
    end
  end
end  

% add intercept
y = [ones(n,1) y];

end
