%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {@var{FD} =} fullDDes (@var{pars})
%% 
%% Given the design parameters @var{pars}, construct a dummy-coded matrix
%% containing all possible profiles.
%% 
%% Input args: array @var{pars} of design parameters 
%% (see field @code{pars} in @code{initsettings}).
%% 
%% Output: dummy-coded regression matrix @var{FD}
%% of all possible profiles, with
%% each row corresponding to a different profile. 
%% The first column (intercept) is made of ones,
%% and the remaining columns describe attribute main effects.
%% Profiles are ordered row by row in such a way, that the first
%% attributes of @car{pars} vary slower than the last ones.
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function FD = fullDDes(pars)    
dumpars = pars - 1;
for i=1:length(pars)

% Rprod: consecutive repetitions of a level in a column
% repvec: minimal column vector containing all levels
% Lprod: repetitions of repvec over the whole column 
Rprod = prod([pars 1](i+1:end));
Lprod = prod([1 pars](1:i));
  for i2=1:dumpars(i)
    repvec = zeros(Rprod*pars(i),1) ;
    repvec(Rprod*i2+1:Rprod*(i2+1),1)= 1;
    FD(:,sum(dumpars(1:(i-1)))+i2) = repmat(repvec,Lprod,1);
  end  
end

% add intercept
FD = [ones(prod(pars),1) FD];

end 
