%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {@var{s} =} initsettings ()
%% 
%% Initialize a structure containing the experimental settings.
%% 
%% Output: structure @var{s} containing empty field arrays,
%% and assigned field names.
%% It follows a description of the field names of @var{s}.
%% 
%% @code{pars}: array describing the design parameters.  
%% For example,
%% @example
%% @var{s}.pars = [2 4 4]
%% @end example
%% corresponds to a design made of three attributes, 
%% with 2, 4 and 4 levels, respectively. 
%%
%% @code{b}: number of respondents.
%%
%% @code{k}: number of profiles (cards) assigned to each respondent
%% (excluding the concurrence profiles).
%% 
%% @code{v}: number of regression profiles.
%% This is also equal to the number of different profiles in the questionnaire.
%% 
%% @code{r}: number of profile replications in the questionnaire.
%% 
%% @code{mFit}: number of different tries
%% for the modified Fedorov algorithm (see @code{mFed_it}).
%% 
%% @code{concprofs}: matrix containing the concurrence 
%% profiles, that will not be present in the D-optimal design.
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn 

function s = initsettings()

s = struct( 'pars',  [],...
            'b',     [],...
            'k',     [],...
            'v',     [],...
            'r',     [],...
            'mFit',  [],...
            'concprofs', []
            );
end              
