%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {[@var{X} @var{inds}]  =} randD (@var{v}, @var{FD})
%% 
%% Construct a random design with @var{v} profiles.
%% This function is used to initialize starting design in @code{mFed_it}.
%% 
%% The random profiles are taken from the list @var{FD}. 
%% 
%% Input args:
%% Number @var{v} of profiles in the random design
%% (@var{v} must be larger than the number of columns of @var{FD});
%% Full array @var{FD} of possible profiles
%% (see @code{fullDDes});
%% 
%% Output:
%% Random design matrix @var{X}. 
%% Indices @var{inds} of the profiles belonging to @var{X},
%% calculated as the row number of the corresponding profile in @var{FD}.
%% 
%% @seealso{fullDDes, mFed_it}
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function [Xrand idxs] = randD(v,FD)

if v < size(FD,2)
  error('The number v of regression profiles cannot be smaller than %i, the number of regression parameters.', size(FD,2));
end

vfull = size(FD,1);	

rk=0;
while rk!= size(FD,2)
  r = randperm(vfull)(1:v);
  X = FD(r,:);
  rk = rank(X'*X);
end

Xrand = X;
idxs = r;

end
