%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} @var{y} = readQuest (@var{bdplan}, @var{quest}, @var{v})
%% 
%% Calculate the vector @var{y} describing the preference share
%% directly measured from the questionnaire.
%% 
%% Input args:
%% Block design plan @var{bdplan};
%% Questionnaire results @var{quest}
%% (a matrix of the same size of @var{bdplan},
%% containing the corresponding respondents' answers 
%% in form of 0's and 1's);
%% Number @var{v} of profiles in the block design.
%% 
%% Output:
%% Vector @var{y} containing the preference share of the @var{v} profiles
%% as measured by the questionnaire.
%% The elements of @var{y} are averages of the respondent's answers over the r profile replications.
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function y = readQuest(bdplan,quest,v)

y = zeros(1,v);

b = size(bdplan,1);
r = b*size(bdplan,2)/v;

for i=1:b
y(bdplan(i,:)) = y(bdplan(i,:)) + quest(i,:)/r; 
end

y=y';

end
