%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} {@var{y} =} undummy (@var{X}, @var{pars})
%% @deftypefnx {Function File} {@var{y} =} undummy (@var{X}, @var{pars}, @var{intercept})
%% 
%% Transform the dummy-coded regression matrix @var{X} in factorial form,
%% with level labels corresponding to integer numbers starting from 1.
%% 
%% Input args: 
%% Dummy-coded regression matrix @var{X};
%% Array @var{pars} of design parameters
%% (see field @code{pars} in @code{initsettings.m});
%% String @var{intercept}, either @qcode{'True'} or @qcode{'False'},
%% depending on whether @var{X} has an intercept at the first column;
%% if the function is called with only two arguments,
%% @example
%% @var{intercept} = 'True'
%% @end example
%% by default.
%% 
%% Output:
%% Design matrix @var{y}, with one column per attribute.
%% Levels are denoted by positive integers
%% in increasing order and starting from 1.
%%
%% @seealso{dumenc}
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function y = undummy(X,pars,varargin)

% manage args in
if nargin > 3
  error('Too many args in')
end  

if nargin==2 || strcmp(varargin{1},'True')
  X(:,1) = [];
elseif ~strcmp(varargin{1},'False')
  error("When specified, variable 'intercept' must either be 'True' or 'False'")
end  

N = size(X,1);
dumpars = pars - 1;
for n =1:N
  for i=1:length(pars)
    ind = find(X(n,1+sum(dumpars(1:(i-1))):sum(dumpars(1:i))));
    if !isempty(ind)
      uX(n,i) = ind+1;
    else  
       uX(n,i) = 1;
    end
  end
end
y =  uX;

end
