%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} writeD (@var{fname}, @var{Ddes})
%% @deftypefnx {Function File} writeD (@var{fname}, @var{Ddes}, 'delimiter', @var{dlm})
%% 
%% Print the design matrix @var{Ddes} (in factorial form) on @var{fname},
%% with a further column to the left to enumerate the profiles.
%%
%% Column headers indicating the profiles and labeling the attributes
%%  and levels are printed as well.
%% 
%% If called with two arguments, use ';' as default delimiter for column separation.
%% If called with four arguments, the string @var{dlm} specifies the delimiter to be used.
%%
%% Input args:
%% String @var{fname} indicating the path of the file on which the matrix
%% has to be written;
%% Matrix @var{Ddes}, as given for instance by the output of @code{mFed_it}.
%%
%% @seealso{mFed_it}
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function writeD(fname,Ddes,varargin)

% manage args in
if nargin == 4 && strcmp(varargin(1),'delimiter')
  dlm = varargin(2){1};
elseif nargin == 2
  dlm = ';'; % set default delimiter
else
  error('wrong delimiter specification') 
end

fid = fopen(fname,'w');

% write column headers
fprintf(fid,['profile' dlm])
for i=1:size(Ddes,2)
  fprintf(fid,'attribute%i',i)
  if i<size(Ddes,2)
    fprintf(fid,dlm)
  end  
end  
fprintf(fid,'\r\n')
fclose(fid);

% write design matrix
Ddes = [(1:size(Ddes,1))' Ddes];  
dlmwrite(fname,Ddes,'-append','delimiter',dlm);

end
