%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} writeDvec (@var{fname}, @var{beta}, @var{pars}) 
%% @deftypefnx {Function File} writeDvec (@var{fname}, @var{beta}, @var{pars}, 'delimiter', @var{dlm}) 
%%
%% Print the dummy-coded vector @var{beta} on @var{fname}.
%%
%% Row headers indicating the intercept term and labeling the attributes and levels are printed as well.
%%
%% If called with two arguments, use ';' as default delimiter for column separation.
%% If called with four arguments, the string @var{dlm} specifies the delimiter to be used.
%%
%% Input args:
%% String @var{fname} indicating the path of the file on which the dummy vector
%% has to be written;
%% Dummy vector @var{beta}, as given for instance by the output of @code{LogReg};
%% Design parameters @var{pars} (used for row headers, see field @code{s.pars} in @code{initsettings}).
%%
%% @seealso{LogReg}
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function writeDvec(fname,beta,pars,varargin)

% manage args in
if nargin == 5 && strcmp(varargin(1),'delimiter')
  dlm = varargin(2){1};
elseif nargin == 3
  dlm = ';'; % set default delimiter
else
  error('wrong delimiter specification') 
end

% dummy levels labeling
dl = [];
for i=1:length(pars)
	for j=2:pars(i)
		dl = [dl; [i,j]];
	end
end  

% print headers and vector
fid = fopen(fname,'w');
fprintf(fid,['intercept_term' dlm '%f\r\n'],beta(1));
for i=2:length(beta)
	fprintf(fid,['attribute%ilevel%i' dlm '%f\r\n'],...
    dl(i-1,1), dl(i-1,2),beta(i));
end
fclose(fid);
end
