%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.

%% -*- texinfo -*-
%% @deftypefn {Function File} writePrefShare (@var{fname}, @var{profs}, @var{y})
%% @deftypefnx {Function File} writePrefShare (@var{fname}, @var{profs}, @var{y}, 'delimiter', @var{dlm})
%%
%% Print the profiles @var{profs} and their estimated preference share @var{y} on @var{fname}.
%% 
%% Column headers labeling the attributes and indicating the preference share column are printed as well.
%%
%% If called with two arguments, use ';' as default delimiter for column separation.
%% If called with four arguments, the string @var{dlm} specifies the delimiter to be used.
%%
%% Input args:
%% String @var{fname} indicating the path of the file on which the profiles and the preference share
%% have to be written;
%% Profiles @var{profs} in factorial form (one row for each profile);
%% Column vector @var{y}, the elements of which describe the estimated preference share for each profile contained in @var{profs}.
%%
%% Programmed by Simone Balmelli (2018).
%% @end deftypefn

function writePrefShare(fname,profs,y,varargin)

% manage args in
if nargin == 5 && strcmp(varargin(1),'delimiter')
  dlm = varargin(2){1};
elseif nargin == 3
  dlm = ';'; % set default delimiter
else
  error('wrong argument specification') 
end

fid = fopen(fname,'w');

% write header
for i=1:size(profs,2)
	fprintf(fid,['attribute%i' dlm],i);
end
fprintf(fid,'preference_share\r\n')

% write profiles and preference share
for i=1:size(profs,1)
	for j=1:size(profs,2)
		fprintf(fid,['%i' dlm],profs(i,j));
	end
	fprintf(fid,'%f\r\n',y(i));
end
fclose(fid);

end
