%% Copyright (C) 2018 Simone Balmelli and Francesco Moresino
%%
%% This file is part of PrefShare.
%%
%% PrefShare is free software: you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation, either version 3 of the License, or
%% (at your option) any later version.
%%
%% PrefShare is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with PrefShare. If not, see <http://www.gnu.org/licenses/>.


%% ================= Experimental design ===================
%% =========================================================
%% Generate a D-optimal design and a random block design.
%% Save them in the 'output' directory.
%%
%% The experimental settings are included in the structure 's',
%% which describes the type of factorial design that is used,
%% the questionnaire split and regression parameters,
%% the competition's profiles and the number of independent iterations
%% of the 'mFed' algorithm.
%%
%% The user has two options:
%%   1) Customize and use the default settings that are 
%%      explicitly written in this file.
%%      In this case, manually modify the settings in the place 
%%      indicated below, and select 'Use the default settings' in the 
%%      dialog window that appears when this script is launched.
%%
%%      Use this option if you have specific requirements
%%      about the questionnaire split parameters b,k,v.
%%      Recall that v must be an integer divisor of b*k,
%%      otherwise the program will raise an error.
%%
%%  2)  Follow the interactive procedure to modify the default
%%      settings (select 'Modify the default settings' in the
%%      dialog window) or to enter new settings 
%%      (select 'Enter new settings'). This procedure will help
%%      you to choose appropriate questionnaire split parameters.
%%
%% Type 'help initsettings' for more informations
%% about the experimental settings.
%% Type 'help Run' for some information about the main 
%% algorithms evaluated by this script.
%%
%% Programmed by Simone Balmelli (2018).

addpath('../functions')

%% =================== define settings =====================
%
s = initsettings();

%% The following default settings
%% may be modified by the user
%% Note that v must be a divisor of k*b
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
s.pars = [4 3 3 3 3 2 2 2]; % number of levels for each attribute
s.b = 259;                  % number of respondents
s.k = 10;                   % number of cards per respondent
s.v = 2591;                 % number of regression design profiles
s.mFit = 100;               % number of independent tries of 'mFed'
s.concprofs = [1 1 1 1 1 1 1 1;...
               4 3 3 3 3 2 2 2];  % competition's profiles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

s.r = s.b*s.k/s.v;
s = dialog(s);

%% ====================== run program ======================
%
y=Run(s);
fprintf('\n');

%% ====================== save results =====================
%
bdfname = ['../output/questionnaire_split.csv'];
writeBD(bdfname,y.B,'delimiter',';');  
fprintf(["Questionnaire split succesfully written in '",...
bdfname "'.\n"]);

dfname = ['../output/D_basis.csv'];
writeD(dfname,y.D,'delimiter',';');
fprintf(["D-optimal basis succesfully written in '",...
dfname "'.\n"]);

save '../output/parameters.csv' s;
